Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(227)

Unified Diff: src/gpu/GrBufferedDrawTarget.h

Issue 1261033002: Rename GrInOrderDrawBuffer to GrBufferedDrawTarget (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: renames Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « samplecode/SampleManyRects.cpp ('k') | src/gpu/GrBufferedDrawTarget.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrBufferedDrawTarget.h
diff --git a/src/gpu/GrInOrderDrawBuffer.h b/src/gpu/GrBufferedDrawTarget.h
similarity index 85%
rename from src/gpu/GrInOrderDrawBuffer.h
rename to src/gpu/GrBufferedDrawTarget.h
index 908632ce6dafb94b2989181e6eb6ffdb849fe2cc..df9ad463bdca80098fd9224415574dad63f942ab 100644
--- a/src/gpu/GrInOrderDrawBuffer.h
+++ b/src/gpu/GrBufferedDrawTarget.h
@@ -5,34 +5,30 @@
* found in the LICENSE file.
*/
-#ifndef GrInOrderDrawBuffer_DEFINED
-#define GrInOrderDrawBuffer_DEFINED
+#ifndef GrBufferedDrawTarget_DEFINED
+#define GrBufferedDrawTarget_DEFINED
#include "GrDrawTarget.h"
#include "GrCommandBuilder.h"
#include "SkChunkAlloc.h"
/**
* GrInOrderDrawBuffer is an implementation of GrDrawTarget that queues up draws for eventual
* playback into a GrGpu. In theory one draw buffer could playback into another. When index or
* vertex buffers are used as geometry sources it is the callers the draw buffer only holds
* references to the buffers. It is the callers responsibility to ensure that the data is still
* valid when the draw buffer is played back into a GrGpu. Similarly, it is the caller's
* responsibility to ensure that all referenced textures, buffers, and render-targets are associated
* in the GrGpu object that the buffer is played back into. The buffer requires VB and IB pools to
* store geometry.
*/
-class GrInOrderDrawBuffer : public GrClipTarget {
+class GrBufferedDrawTarget : public GrClipTarget {
public:
/**
- * Creates a GrInOrderDrawBuffer
+ * Creates a GrBufferedDrawTarget
*
* @param context the context object that owns this draw buffer.
*/
- GrInOrderDrawBuffer(GrContext* context);
+ GrBufferedDrawTarget(GrContext* context);
- ~GrInOrderDrawBuffer() override;
+ ~GrBufferedDrawTarget() override;
void clearStencilClip(const SkIRect& rect,
bool insideClip,
« no previous file with comments | « samplecode/SampleManyRects.cpp ('k') | src/gpu/GrBufferedDrawTarget.cpp » ('j') | no next file with comments »
@@ -5,34 +5,30 @@
#include "SkChunkAlloc.h"
/**
- * GrInOrderDrawBuffer is an implementation of GrDrawTarget that queues up draws for eventual
- * playback into a GrGpu. In theory one draw buffer could playback into another. When index or
- * vertex buffers are used as geometry sources it is the callers the draw buffer only holds
- * references to the buffers. It is the callers responsibility to ensure that the data is still
- * valid when the draw buffer is played back into a GrGpu. Similarly, it is the caller's
- * responsibility to ensure that all referenced textures, buffers, and render-targets are associated
- * in the GrGpu object that the buffer is played back into. The buffer requires VB and IB pools to
- * store geometry.
+ * GrBufferedDrawTarget is an implementation of GrDrawTarget that queues up draws for eventual
+ * playback into a GrGpu. In theory one draw buffer could playback into another. Similarly, it is
+ * the caller's responsibility to ensure that all referenced textures, buffers, and render-targets
+ * are associated in the GrGpu object that the buffer is played back into.
*/

Powered by Google App Engine
This is Rietveld 408576698